@@ -22,21 +22,23 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.ByteBuffer;
 import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.Enumeration;
 import java.util.zip.CRC32;
 
-import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.utils.CharsetNames;
 import org.junit.jupiter.api.Test;
 
-public class UTF8ZipFilesTest extends AbstractTestCase {
+public class UTF8ZipFilesTest extends AbstractTest {
 
     private static final String CP437 = "cp437";
     private static final String ASCII_TXT = "ascii.txt";
@@ -54,10 +56,7 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
         assertNotSame(b, ze.getRawName());
     }
 
-    private static void assertUnicodeName(final ZipArchiveEntry ze,
-                                          final String expectedName,
-                                          final String encoding)
-        throws IOException {
+    private static void assertUnicodeName(final ZipArchiveEntry ze, final String expectedName, final String encoding) throws IOException {
         if (!expectedName.equals(ze.getName())) {
             final UnicodePathExtraField ucpf = findUniCodePath(ze);
             assertNotNull(ucpf);
@@ -66,41 +65,30 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
             final ByteBuffer ne = enc.encode(ze.getName());
 
             final CRC32 crc = new CRC32();
-            crc.update(ne.array(), ne.arrayOffset(),
-                       ne.limit() - ne.position());
+            crc.update(ne.array(), ne.arrayOffset(), ne.limit() - ne.position());
 
             assertEquals(crc.getValue(), ucpf.getNameCRC32());
             assertEquals(expectedName, new String(ucpf.getUnicodeName(), UTF_8));
         }
     }
 
-    private static void createTestFile(final File file, final String encoding,
-                                       final boolean withEFS,
-                                       final boolean withExplicitUnicodeExtra)
-        throws IOException {
+    private static void createTestFile(final File file, final String encoding, final boolean withEFS, final boolean withExplicitUnicodeExtra)
+            throws IOException {
 
         final ZipEncoding zipEncoding = ZipEncodingHelper.getZipEncoding(encoding);
 
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file)) {
             zos.setEncoding(encoding);
             zos.setUseLanguageEncodingFlag(withEFS);
-            zos.setCreateUnicodeExtraFields(withExplicitUnicodeExtra ?
-                    ZipArchiveOutputStream
-                            .UnicodeExtraFieldPolicy.NEVER
-                    : ZipArchiveOutputStream
-                    .UnicodeExtraFieldPolicy.ALWAYS);
+            zos.setCreateUnicodeExtraFields(
+                    withExplicitUnicodeExtra ? ZipArchiveOutputStream.UnicodeExtraFieldPolicy.NEVER : ZipArchiveOutputStream.UnicodeExtraFieldPolicy.ALWAYS);
 
             ZipArchiveEntry ze = new ZipArchiveEntry(OIL_BARREL_TXT);
-            if (withExplicitUnicodeExtra
-                    && !zipEncoding.canEncode(ze.getName())) {
+            if (withExplicitUnicodeExtra && !zipEncoding.canEncode(ze.getName())) {
 
                 final ByteBuffer en = zipEncoding.encode(ze.getName());
 
-                ze.addExtraField(new UnicodePathExtraField(ze.getName(),
-                        en.array(),
-                        en.arrayOffset(),
-                        en.limit()
-                                - en.position()));
+                ze.addExtraField(new UnicodePathExtraField(ze.getName(), en.array(), en.arrayOffset(), en.limit() - en.position()));
             }
 
             zos.putArchiveEntry(ze);
@@ -108,16 +96,11 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
             zos.closeArchiveEntry();
 
             ze = new ZipArchiveEntry(EURO_FOR_DOLLAR_TXT);
-            if (withExplicitUnicodeExtra
-                    && !zipEncoding.canEncode(ze.getName())) {
+            if (withExplicitUnicodeExtra && !zipEncoding.canEncode(ze.getName())) {
 
                 final ByteBuffer en = zipEncoding.encode(ze.getName());
 
-                ze.addExtraField(new UnicodePathExtraField(ze.getName(),
-                        en.array(),
-                        en.arrayOffset(),
-                        en.limit()
-                                - en.position()));
+                ze.addExtraField(new UnicodePathExtraField(ze.getName(), en.array(), en.arrayOffset(), en.limit() - en.position()));
             }
 
             zos.putArchiveEntry(ze);
@@ -126,16 +109,11 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
 
             ze = new ZipArchiveEntry(ASCII_TXT);
 
-            if (withExplicitUnicodeExtra
-                    && !zipEncoding.canEncode(ze.getName())) {
+            if (withExplicitUnicodeExtra && !zipEncoding.canEncode(ze.getName())) {
 
                 final ByteBuffer en = zipEncoding.encode(ze.getName());
 
-                ze.addExtraField(new UnicodePathExtraField(ze.getName(),
-                        en.array(),
-                        en.arrayOffset(),
-                        en.limit()
-                                - en.position()));
+                ze.addExtraField(new UnicodePathExtraField(ze.getName(), en.array(), en.arrayOffset(), en.limit() - en.position()));
             }
 
             zos.putArchiveEntry(ze);
@@ -147,46 +125,22 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
     }
 
     private static UnicodePathExtraField findUniCodePath(final ZipArchiveEntry ze) {
-        return (UnicodePathExtraField)
-            ze.getExtraField(UnicodePathExtraField.UPATH_ID);
+        return (UnicodePathExtraField) ze.getExtraField(UnicodePathExtraField.UPATH_ID);
     }
 
-    private static void testFile(final File file, final String encoding)
-        throws IOException {
-        ZipFile zf = null;
-        try {
-            zf = new ZipFile(file, encoding, false);
-
+    private static void testFile(final File file, final String encoding) throws IOException {
+        try (ZipFile zf = ZipFile.builder().setFile(file).setCharset(encoding).setUseUnicodeExtraFields(false).get()) {
             final Enumeration<ZipArchiveEntry> e = zf.getEntries();
             while (e.hasMoreElements()) {
                 final ZipArchiveEntry ze = e.nextElement();
-
                 if (ze.getName().endsWith("sser.txt")) {
                     assertUnicodeName(ze, OIL_BARREL_TXT, encoding);
-
                 } else if (ze.getName().endsWith("_for_Dollar.txt")) {
                     assertUnicodeName(ze, EURO_FOR_DOLLAR_TXT, encoding);
                 } else if (!ze.getName().equals(ASCII_TXT)) {
-                    throw new AssertionError("Unrecognized ZIP entry with name ["
-                                             + ze.getName() + "] found.");
+                    fail("Unrecognized ZIP entry with name [" + ze.getName() + "] found.");
                 }
             }
-        } finally {
-            ZipFile.closeQuietly(zf);
-        }
-    }
-
-    private static void testFileRoundtrip(final String encoding, final boolean withEFS,
-                                          final boolean withExplicitUnicodeExtra)
-        throws IOException {
-
-        final File file = File.createTempFile(encoding + "-test", ".zip");
-        file.deleteOnExit();
-        try {
-            createTestFile(file, encoding, withEFS, withExplicitUnicodeExtra);
-            testFile(file, encoding);
-        } finally {
-            tryHardToDelete(file);
         }
     }
 
@@ -199,80 +153,59 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
         }
     }
 
-    /**
-     * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-479">COMPRESS-479</a>
-     */
     @Test
-    public void streamSkipsOverUnicodeExtraFieldWithUnsupportedVersion() throws IOException {
-        try (InputStream archive = newInputStream("COMPRESS-479.zip");
-             ZipArchiveInputStream zi = new ZipArchiveInputStream(archive)) {
-            assertEquals(OIL_BARREL_TXT, zi.getNextEntry().getName());
-            assertEquals("%U20AC_for_Dollar.txt", zi.getNextEntry().getName());
-            assertEquals(ASCII_TXT, zi.getNextEntry().getName());
-        }
-    }
-
-    @Test
-    public void testASCIIFileRoundtripExplicitUnicodeExtra()
-        throws IOException {
+    public void testASCIIFileRoundtripExplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CharsetNames.US_ASCII, false, true);
     }
 
     @Test
-    public void testASCIIFileRoundtripImplicitUnicodeExtra()
-        throws IOException {
+    public void testASCIIFileRoundtripImplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CharsetNames.US_ASCII, false, false);
     }
 
     @Test
-    public void testCP437FileRoundtripExplicitUnicodeExtra()
-        throws IOException {
+    public void testCP437FileRoundtripExplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CP437, false, true);
     }
 
     @Test
-    public void testCP437FileRoundtripImplicitUnicodeExtra()
-        throws IOException {
+    public void testCP437FileRoundtripImplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CP437, false, false);
     }
 
+    private void testFileRoundtrip(final String encoding, final boolean withEFS, final boolean withExplicitUnicodeExtra) throws IOException {
+        final File file = createTempFile(encoding + "-test", ".zip");
+        createTestFile(file, encoding, withEFS, withExplicitUnicodeExtra);
+        testFile(file, encoding);
+    }
+
     @Test
     public void testRawNameReadFromStream() throws IOException {
         try (ZipArchiveInputStream zi = new ZipArchiveInputStream(newInputStream("utf8-7zip-test.zip"), CP437, false)) {
-            assertRawNameOfAcsiiTxt((ZipArchiveEntry) zi.getNextEntry());
+            assertRawNameOfAcsiiTxt(zi.getNextEntry());
         }
     }
 
     @Test
-    public void testRawNameReadFromZipFile()
-        throws IOException {
+    public void testRawNameReadFromZipFile() throws IOException {
         final File archive = getFile("utf8-7zip-test.zip");
-        ZipFile zf = null;
-        try {
-            zf = new ZipFile(archive, CP437, false);
+        try (ZipFile zf = ZipFile.builder().setFile(archive).setCharset(CP437).setUseUnicodeExtraFields(false).get()) {
             assertRawNameOfAcsiiTxt(zf.getEntry(ASCII_TXT));
-        } finally {
-            ZipFile.closeQuietly(zf);
         }
     }
 
     /*
      * 7-ZIP created archive, uses EFS to signal UTF-8 file names.
      *
-     * 7-ZIP doesn't use EFS for strings that can be encoded in CP437
-     * - which is true for OIL_BARREL_TXT.
+     * 7-ZIP doesn't use EFS for strings that can be encoded in CP437 - which is true for OIL_BARREL_TXT.
      */
     @Test
     public void testRead7ZipArchive() throws IOException {
         final File archive = getFile("utf8-7zip-test.zip");
-        ZipFile zf = null;
-        try {
-            zf = new ZipFile(archive, CP437, false);
+        try (ZipFile zf = new ZipFile(archive, CP437, false)) {
             assertNotNull(zf.getEntry(ASCII_TXT));
             assertNotNull(zf.getEntry(EURO_FOR_DOLLAR_TXT));
             assertNotNull(zf.getEntry(OIL_BARREL_TXT));
-        } finally {
-            ZipFile.closeQuietly(zf);
         }
     }
 
@@ -286,26 +219,20 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
     }
 
     /*
-     * WinZIP created archive, uses Unicode Extra Fields but only in
-     * the central directory.
+     * WinZIP created archive, uses Unicode Extra Fields but only in the central directory.
      */
     @Test
     public void testReadWinZipArchive() throws IOException {
         final File archive = getFile("utf8-winzip-test.zip");
-        ZipFile zf = null;
-        try {
-            // fix for test fails on Windows with default charset that is not UTF-8
-            String encoding = null;
-            if (Charset.defaultCharset() != UTF_8) {
-                encoding = UTF_8.name();
-            }
-
-            zf = new ZipFile(archive, encoding, true);
+        // fix for test fails on Windows with default charset that is not UTF-8
+        String encoding = null;
+        if (Charset.defaultCharset() != UTF_8) {
+            encoding = UTF_8.name();
+        }
+        try (ZipFile zf = ZipFile.builder().setFile(archive).setCharset(encoding).setUseUnicodeExtraFields(true).get()) {
             assertCanRead(zf, ASCII_TXT);
             assertCanRead(zf, EURO_FOR_DOLLAR_TXT);
             assertCanRead(zf, OIL_BARREL_TXT);
-        } finally {
-            ZipFile.closeQuietly(zf);
         }
     }
 
@@ -324,27 +251,36 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
         }
     }
 
+    /**
+     * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-479">COMPRESS-479</a>
+     */
     @Test
-    public void testUtf8FileRoundtripExplicitUnicodeExtra()
-        throws IOException {
+    public void testStreamSkipsOverUnicodeExtraFieldWithUnsupportedVersion() throws IOException {
+        try (InputStream archive = newInputStream("COMPRESS-479.zip");
+                ZipArchiveInputStream zi = new ZipArchiveInputStream(archive)) {
+            assertEquals(OIL_BARREL_TXT, zi.getNextEntry().getName());
+            assertEquals("%U20AC_for_Dollar.txt", zi.getNextEntry().getName());
+            assertEquals(ASCII_TXT, zi.getNextEntry().getName());
+        }
+    }
+
+    @Test
+    public void testUtf8FileRoundtripExplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CharsetNames.UTF_8, true, true);
     }
 
     @Test
-    public void testUtf8FileRoundtripImplicitUnicodeExtra()
-        throws IOException {
+    public void testUtf8FileRoundtripImplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CharsetNames.UTF_8, true, false);
     }
 
     @Test
-    public void testUtf8FileRoundtripNoEFSExplicitUnicodeExtra()
-        throws IOException {
+    public void testUtf8FileRoundtripNoEFSExplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CharsetNames.UTF_8, false, true);
     }
 
     @Test
-    public void testUtf8FileRoundtripNoEFSImplicitUnicodeExtra()
-        throws IOException {
+    public void testUtf8FileRoundtripNoEFSImplicitUnicodeExtra() throws IOException {
         testFileRoundtrip(CharsetNames.UTF_8, false, false);
     }
 
@@ -352,46 +288,29 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
     public void testUtf8Interoperability() throws IOException {
         final File file1 = getFile("utf8-7zip-test.zip");
         final File file2 = getFile("utf8-winzip-test.zip");
-
-        testFile(file1,CP437);
-        testFile(file2,CP437);
-
+        testFile(file1, CP437);
+        testFile(file2, CP437);
     }
 
     @Test
-    public void testZipArchiveInputStreamReadsUnicodeFields()
-        throws IOException {
-        final File file = File.createTempFile("unicode-test", ".zip");
-        file.deleteOnExit();
-        ZipFile zf = null;
-        try {
-            createTestFile(file, CharsetNames.US_ASCII, false, true);
-            zf = new ZipFile(file, CharsetNames.US_ASCII, true);
+    public void testZipArchiveInputStreamReadsUnicodeFields() throws IOException {
+        final File file = createTempFile("unicode-test", ".zip");
+        createTestFile(file, CharsetNames.US_ASCII, false, true);
+        try (ZipFile zf = ZipFile.builder().setFile(file).setCharset(StandardCharsets.US_ASCII).setUseUnicodeExtraFields(true).get()) {
             assertNotNull(zf.getEntry(ASCII_TXT));
             assertNotNull(zf.getEntry(EURO_FOR_DOLLAR_TXT));
             assertNotNull(zf.getEntry(OIL_BARREL_TXT));
-        } finally {
-            ZipFile.closeQuietly(zf);
-            tryHardToDelete(file);
         }
     }
 
     @Test
     public void testZipFileReadsUnicodeFields() throws IOException {
-        final File file = File.createTempFile("unicode-test", ".zip");
-        file.deleteOnExit();
-        ZipArchiveInputStream zi = null;
-        try {
-            createTestFile(file, CharsetNames.US_ASCII, false, true);
-            zi = new ZipArchiveInputStream(Files.newInputStream(file.toPath()), CharsetNames.US_ASCII, true);
+        final File file = createTempFile("unicode-test", ".zip");
+        createTestFile(file, CharsetNames.US_ASCII, false, true);
+        try (ZipArchiveInputStream zi = new ZipArchiveInputStream(Files.newInputStream(file.toPath()), CharsetNames.US_ASCII, true)) {
             assertEquals(OIL_BARREL_TXT, zi.getNextEntry().getName());
             assertEquals(EURO_FOR_DOLLAR_TXT, zi.getNextEntry().getName());
             assertEquals(ASCII_TXT, zi.getNextEntry().getName());
-        } finally {
-            if (zi != null) {
-                zi.close();
-            }
-            tryHardToDelete(file);
         }
     }
 
@@ -399,12 +318,11 @@ public class UTF8ZipFilesTest extends AbstractTestCase {
      * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-479">COMPRESS-479</a>
      */
     @Test
-    public void zipFileSkipsOverUnicodeExtraFieldWithUnsupportedVersion() throws IOException {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
+    public void testZipFileSkipsOverUnicodeExtraFieldWithUnsupportedVersion() throws IOException {
+        try (ZipFile zf = ZipFile.builder().setFile(getFile("COMPRESS-479.zip")).get()) {
             assertNotNull(zf.getEntry(ASCII_TXT));
             assertNotNull(zf.getEntry("%U20AC_for_Dollar.txt"));
             assertNotNull(zf.getEntry(OIL_BARREL_TXT));
         }
     }
 }
-
